==> ejc-panhuo-impl-3.0.0-20200818.125119-10-sources.jar: com/ejianc/business/panhuo/bean/AddressEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 地址管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_address")
public class AddressEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目主键
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织主键
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="user_id")
    private java.lang.Long userId; // 用户主键
    @TableField(value="lon")
    private java.lang.Double lon; // 经度
    @TableField(value="lat")
    private java.lang.Double lat; // 纬度
    @TableField(value="first_location")
    private java.lang.String firstLocation; // 所在地一级区域
    @TableField(value="second_location")
    private java.lang.String secondLocation; // 所在地二级区域
    @TableField(value="third_location")
    private java.lang.String thirdLocation; // 所在地三级区域
    @TableField(value="fourth_location")
    private java.lang.String fourthLocation; // 所在地四级区域
    @TableField(value="location")
    private java.lang.String location; // 所在地末级区域
    @TableField(value="address")
    private java.lang.String address; // 详细地址
    @TableField(value="phone")
    private java.lang.String phone; // 联系方式
    @TableField(value="name")
    private java.lang.String name; // 联系人
    @TableField(value="isquote")
    private java.lang.Integer isquote; // 0=是，1=不是


    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目主键
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public java.lang.Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(java.lang.Long userId) {
        this.userId = userId;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddress() {
        return address;
    }

    /**
     * 详细地址
     */
    public void setAddress(java.lang.String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public java.lang.Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(java.lang.Integer isquote) {
        this.isquote = isquote;
    }
    
}

==> ejc-panhuo-impl-3.0.0-20251013.062808-226-sources.jar: com/ejianc/business/panhuo/bean/AddressEntity.java <==
package com.ejianc.business.panhuo.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 地址管理
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_address")
public class AddressEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目主键
    @TableField(value="org_id")
    private java.lang.Long orgId; // 组织主键
    @TableField(value="org_name")
    private java.lang.String orgName; // 组织名称
    @TableField(value="user_id")
    private java.lang.Long userId; // 用户主键
    @TableField(value="lon")
    private java.lang.Double lon; // 经度
    @TableField(value="lat")
    private java.lang.Double lat; // 纬度
    @TableField(value="first_location")
    private java.lang.String firstLocation; // 所在地一级区域
    @TableField(value="second_location")
    private java.lang.String secondLocation; // 所在地二级区域
    @TableField(value="third_location")
    private java.lang.String thirdLocation; // 所在地三级区域
    @TableField(value="fourth_location")
    private java.lang.String fourthLocation; // 所在地四级区域
    @TableField(value="location")
    private java.lang.String location; // 所在地末级区域
    @TableField(value="address")
    private java.lang.String address; // 详细地址
    @TableField(value="project_address")
    private java.lang.String projectAddress; // 项目地址
    @TableField(value="detail_address")
    private java.lang.String detailAddress; // 地址
    @TableField(value="phone")
    private java.lang.String phone; // 联系方式
    @TableField(value="name")
    private java.lang.String name; // 联系人
    @TableField(value="isquote")
    private java.lang.Integer isquote; // 0=是，1=不是

    public String getProjectAddress() {
        return projectAddress;
    }

    public void setProjectAddress(String projectAddress) {
        this.projectAddress = projectAddress;
    }

    public String getDetailAddress() {
        return detailAddress;
    }

    public void setDetailAddress(String detailAddress) {
        this.detailAddress = detailAddress;
    }

    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 项目主键
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目主键
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public java.lang.Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(java.lang.Long userId) {
        this.userId = userId;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddress() {
        return address;
    }

    /**
     * 详细地址
     */
    public void setAddress(java.lang.String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public java.lang.Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(java.lang.Integer isquote) {
        this.isquote = isquote;
    }
    
}
